Hydraulic
=========

A python package to compute pressure, flows and temperatures in hydraulic circuits

.. image:: https://raw.githubusercontent.com/Dessia-tech/hydraulic/master/doc/source/images/circuit4.png

Installing
----------

.. code::

  pip(3) install hydraulic

Documentation
-------------
https://hydraulic.readthedocs.io/en/latest/

